@@ -24,10 +24,10 @@ import ch.qos.logback.core.util.CoreTestConstants;
 
 import java.io.File;
 import java.io.IOException;
-import java.sql.Date;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Calendar;
+import java.util.Date;
 import java.util.Enumeration;
 import java.util.List;
 import java.util.concurrent.Future;
@@ -279,6 +279,6 @@ public class ScaffoldingForRollingTests {
                 new RuntimeException("unexpected exception while testing", e);
             }
         }
-
+        futureList.clear();
     }
 }
